;Betriebssystem fr die 8035-Zelle, 0...1kB im EPROM
;Version 13.3.91
;
;Besondere Adressen des internen RAM:
;61,62 Hi,Lo- aktuelle RAM-Adresse
;59,60 Hi,Lo- Wartezeit im ms
;55..58 aktive Kanle 1...4, 0=aus
;53,54 Hi,Lo- Lnge eines Datenblocks
;51,52 Hi,Lo- Zhler fr Blocklnge
;Besonders reservierte Register:
;R7 = Y in SIMPEL
;R6 = PUSH/POP-Speicher in SIMPEL

;Nach dem Programmstart wird ein Kommando ber die RS232
;erwartet, das zu den verschiedenen Grundfunktionen fhrt.
;Befindet sich die Autostart-Information "129" oder "130" in
;der Speicherzelle 03FF des batteriegepufferten RAMs, dann wird
;sofort eine Messung bzw ein User-Programm gestartet.
;5-Sekunden-Drcken der Starttaste nach RESETbewirkt ein
;ALL-RESET

.org 00h
Anfa           jmp     Anfang
.org 03h
               jmp     Inter
Anfang         nop                     ;Abfrage Status
Anf            en      i    
               dis     tcnti
               strt    t
               jnt0    Allreset
               orl     p2,#255
               orl     p1,#255
Befehle        call    SystemRAM        ;Autostart?
               call    LiesRAM
               jb7     Start
BefRS          call    Empf             ;Befehlsinterpreter:
               jz      BefRS
               dec     a
               jz      Bef1
               dec     a
               jz      Bef2             ;Kommando "2" erkannt
               dec     a
               jz      Bef3             ;usw.
               dec     a
               jz      Bef4             ;
               dec     a
               jz      Bef5             ;
               dec     a
               jz      Bef6             ;
               dec     a
               jz      Bef7             ;
               dec     a
               jz      Bef8             ;
               dec     a
               jz      Bef9             ;
               dec     a
               jz      Bef10            ;
               dec     a
               jz      Bef11            ;
               dec     a
               jz      Bef12            ;
               dec     a
               jz      Bef13            ;
               dec     a
               jz      Bef14            ;
               dec     a
               jz      Bef15            ;
               dec     a
               jz      Bef16            ;
               dec     a
               jz      Bef17            ;
               dec     a
               jz      Bef18            ;
               dec     a
               jz      Bef19            ;
               jmp     BefRS            ;Ende Interpreterschleife

Bef1           jmp     Messparameter
Bef2           jmp     Lesen
Bef3           jmp     Schrb
Bef4           jmp     Direkt
Bef5           call    SystemRAM
               mov     a,#130
               call    SchreibeRAM
               jmp     Proglad 
Bef6           call    SystemRAM
               mov     a,#130
               call    SchreibeRAM
               jmp     Progsta
Bef7           jmp     Direkt1
Bef8           jmp     PIB1 
Bef9           jmp     BefRS            ;reserviert fr "Start"
Bef10          call    SystemRAM
               mov     a,#129
               call    SchreibeRAM
               jmp     Serie 
Bef11          jmp     Port1 
Bef12          jmp     LiesPort1
Bef13          call    LiesT0
               call    Senden
               jmp     BefRS
Bef14          jmp     Port2
Bef15          jmp     LiesPort2
Bef16          jmp     LiesIRAM
Bef17          jmp     SchrbIRAM
Bef18          jmp     LiesERAM
Bef19          jmp     SchrbERAM



;Autostart: der gelesene Startwert war ber 128 und
;wird hier ausgewertet. 129: Serienmessung, 130: Programmstart
;alle anderen Werte fhren zu einem Neustart ber die
;Interrupt-Prozedur

Start          en      i
               anl     a,#7fh
               dec     a
               jz      SerieStart          ;129
               dec     a
               jz      ProgrammStart       ;130
               jmp     Inter

SerieStart     call    Serie
               jmp     Anfa
ProgrammStart  jmp     Progsta
               jmp     Anfa  



;Interrupt-Serviceroutine, darf auch direkt angesprungen
;werden. Stellt aus jeder Situation den Ausgangszustand des
;Programms wieder her.

Inter          dis     i
               call    SystemRAM
               mov     a,#0           ;Startinfo abschalten
               call    SchreibeRAM
               call    Startbit       ;ein Byte abwarten
               call    EndeInter
               mov     a,#00
               mov     psw,a          ;Stack auf Null setzen
               mov     a,#0
               jmp     Anfang

EndeInter      retr                   ;Interrupt besttigen

;Auswerten der Starttaste nach RESET: 0s<t<1s: nichts,
;1s<t<3s: Messen, 3s<t<5s: Programm, 5s<t<7s: ALL-RESET

Allreset       mov     r2,#50 
Warte20        mov     r3,#20
Warte1         call    Warten         ;1ms
               djnz    r3,Warte1      
               jt0     Anfang         ;Taste frei?
               djnz    r2,Warte20     ;50 mal 20ms
               mov     r2,#100
Warte20b       mov     r3,#20
Warte1b        call    Warten         ;1ms
               djnz    r3,Warte1b     
               jt0     Bef10          ;Taste frei?: Serie
               djnz    r2,Warte20b    ;100 mal 20ms
               mov     r2,#100
Warte20c       mov     r3,#20
Warte1c        call    Warten         ;1ms
               djnz    r3,Warte1c     
               jt0     Bef6           ;Taste frei?: Programm
               djnz    r2,Warte20c    ;250 mal 20ms
               jmp     Inter          ;wenn >6s gedrckt

.org 100h
; rs232 Senden, verwendet r2...r3
;9600 Baud, Sendesignal liegt invertiert an P27
;Interrupt ist fr die Zeit der Ausgabe gesperrt
;Das Stopbit ist sehr kurz, weil nie zwei Bytes
;sofort hintereinander ausgegeben werden

Senden         dis     i              ;Interrupt gesperrt
               mov     r2,#8          ;Zhlschleife 8 Bits
               anl     p2,#7Fh        ;P27=0, Startbit
;              mov     r3,#162        ;1200Baud
               mov     r3,#16         ;9600 Baud
Sch1           djnz    r3,Sch1        ;Warteschleife Startbit
Sp1            clr     c
               rrc     a              ;Datenbit in C schieben
               jc      Sp2
               anl     p2,#7Fh        ;wenn c=0, dann P27=0
               jmp     Sp3
Sp2            orl     p2,#80h        ;wenn c=1, dann P27=1
               orl     p2,#80h
;Sp3            mov     r3,#160       ;1200Baud
Sp3            mov     r3,#15         ;9600 Baud
Sch2           djnz    r3,Sch2        ;Warteschleife Datenbit
               djnz    r2,Sp1         ;8 mal wiederholen
               mov     a,#0
               mov     a,#0
               orl     p2,#80h        ;P27=1, Stopbit
;               mov     r3,#108       ;1200 Baud
               mov     r3,#1          ;kurzes Stopbit, 9600 Baud
Sch3           djnz    r3,Sch3        ;Warteschleife Stopbit
               en      i              ;Interrupt wieder frei
               ret


;rs232 Empfangen, verwendet r2...r4
;Eingang ist INT mit Abfrage ber jni. Baudrate 9600 bei 6MHz
;Hardware-Interrupt ist fr die Zeit der Eingabe gesperrt
;Das Label "Startbit" darf auch extern angesprungen werden,
;wenn ein Signal an INT erkannt wurde.

Empf           dis     i              ;Interrupt sperren
               jni     Startbit       ;Int = 0?
               jmp     Empf           ;wenn Int = 1
;Startbit       mov     r2,#225       ;1200 Baud
Startbit       mov     r2,#25         ;9600 Baud
Sch6           djnz    r2,Sch6        ;Warten 1,5 Startbit
               mov     r3,#8          ;Schleife 8 Bits
Sp6            clr     c              ;c=0
               jni     Null           ;Int = 0 ?
               nop                    ;Zeitausgleich
               cpl     c              ;C=1
               xch     a,r4           ;Byte von r4 holen
               rrc     a              ;c in a schieben
               xch     a,r4           ;Byte wieder nach r4
;               mov     r2,#162       ;1200 Baud
               mov     r2,#15         ;9600 Baud
Sch7           djnz    r2,Sch7        ;Warten Datenbit
               djnz    r3,Sp6         ;8 Bits empfangen?
               mov     a,r4           ;emfangenes Byte in a
               en      i              ;Interrupt wieder frei
               ret
Null           nop                    ;Schleife fr Nullbits:
               clr     c              ;c=0
               xch     a,r4           ;Byte von r4 holen
               rrc     a              ;c in a schieben
               xch     a,r4           ;Byte wieder nach r4
;               mov     r2,#162       ;1200 Baud
               mov     r2,#15         ;9600 Baud
Sch8           djnz    r2,Sch8        ;Warten Datenbit
               djnz    r3,Sp6         ;8 Bits empfangen?
               mov     a,r4           ;empfangenes Byte in a
               en      i              ;Interrupt wieder frei
               ret

;UPD7001-Messen, bergabe des Kanals (1...4) im Akku,
;Ergebnisausgabe im Akku, bentigt ca 0,5ms, verwendet r2
;Datenbertragung seriell getaktet. Schiebetakt ber P11 an
;SCK, Steuerdaten ber P12 an SI, Medaten ber T1 von SO,
;Freigabe ber P10 an CS, Steuern/Ausleseumschaltung ber P13
;an DL. End of Conversion (EOC) wird nicht benutzt, statt
;dessen feste Warteschleife

Messen         anl     p1,#0F0h        ;P10...P13  Null
               mov     r2,#02          ;Zhlschleife 2 Bits
               dec     a               ;Byte 0...3 fr Kanal 1...4
               rr      a               ;Bits 0/1 nach 6/7
               rr      a 
Sl1            rlc     a               ;Kanalbit in c
               jnc     Strobe
               orl     p1,#04          ;wenn c=1, Si = 1
Strobe         orl     p1,#02          ;Clock = 1
               anl     p1,#0FDh        ;Clock = 0
               anl     p1,#0FBh        ;Si = 0
               djnz    r2,Sl1          ;2 mal
               orl     p1,#008h        ;DL=1, Kanal gesendet
               anl     p1,#0F7h        ;DL=0
               orl     p1,#1           ;Cs=1, Messung starten
               mov     r2,#30          ;ca 150 s/6MHz
Sl2            djnz    r2,Sl2          ;Warteschleife
               anl     p1,#0FEh        ;Cs=0
               orl     p1,#08h         ;DL=1, Auslesen
               mov     r2,#08          ;Schleife 8 Bits
Sl3            clr     c               ;c=0
               jnt1    T1aus           ;T1=0?
               cpl     c               ;wenn T1=1, dann c=1
T1aus          rlc     a               ;Datenbit reinschieben
               orl     p1,#02          ;Clock=1
               anl     p1,#0FDh        ;Clock=0
               djnz    r2,Sl3          ;acht mal
               orl     p1,#0Fh         ;P10...P13 = 1
               ret

;Setzen des RAM-Adrepointers (61/62) auf den Anfang des
;Datenbereichs. 0400h (2k). P27 u. P25 bleiben hochgesetzt.
;P26 bleibt unverndert.

AnfangRAM      mov      r1,#61         ;Adresse Hi
 ;             mov      @r1,#0C4h      ;page4, 1k
               in       a,p2
               anl      a,#0C0h        ;P26 u. P27 bleiben
               orl      a,#08h      
               mov      @r1,a          ;page8, 2k
               inc      r1             ;Adresse Lo
               mov      @r1,#0
               ret

;Ein Byte in den Datenbereich schreiben und Adrepointer weiter
;setzen. Beim berschreiten des RAM-Bereichs wird das gesamte
;Programm abgebrochen. P25 (I/O-Select) wird immer nur kurz
;auf Null gesetzt, um das RAM berwiegend zu desaktivieren
;verwendet r1,r2,r6

SchreibeRAM    mov     r1,#61           ;High
               mov     r6,a             ;PUSH
               mov     a,@r1       
               outl    p2,a             ;A8...A12 
               inc     r1               ;62, Low
               mov     a,@r1
               mov     r0,a
               mov     a,r6             ;POP
               movx    @r0,a            ;speichern
               orl     p2,#20h          ;RAM inaktiv, Stromsparen
               mov     a,@r1
               inc     a                ;Adresse erhhen
               mov     @r1,a
               jnz     spr1             ; bertrag?
               dec     r1               ;62, High
               mov     a,@r1
               inc     a
               mov     @r1,a            ;Adrebyte high erhhen
;              anl     a,#8             ;RAM-Obergrenze (2k) erreicht?
               anl     a,#32            ;RAM-Obergrenze (8k) erreicht?
               jz      spr1
               jmp     Endlos           ;Neustart durch Reset erlaubt
spr1           ret

;Lesen eines Bytes aus dem Daten-RAM und erhhen des
;Adrepointers (61/62)
;verwendet r0,r1,r6

LiesRAM        mov     r1,#61           ;High
               mov     a,@r1
               outl    p2,a             ;A8...A12 
               inc     r1               ;62, Low
               mov     a,@r1
               mov     r0,a
               movx    a,@r0            ;lesen
               orl     p2,#20h          ;RAM inaktiv, Stromsparen
               mov     r6,a
               mov     a,@r1
               inc     a                ;Adresse erhhen
               mov     @r1,a
               jnz     spru1            ;bertrag?
               dec     r1               ;61, High
               mov     a,@r1
               inc     a
               mov     @r1,a            ;Adrebyte high erhhen
spru1          mov     a,r6             ;POP
               ret


;Wartezeit bis zur nchsten abgelaufenen Millisekunde abwarten.
;Feinabgleich ntig, da bei 6MHz keine glatte ms mglich.
Warten         jtf     end1ms          ;Timer-berlauf?
               jmp     Warten
end1ms         mov     r6,a
               mov     a,#244          ;1ms/6MHz
               mov     t,a
               mov     a,#0            ;Feinabgleich
               mov     a,#0
               mov     a,#0
               mov     a,#0
               mov     a,r6
               strt    t               ;Timer-Neustart
               ret


;Empfang und Abspeicherung von 8 Steuerbytes fr die Serien-
;messung. Die Steuerbytes wersen in die Adressen 53...60
;geschrieben und zustlich an den Anfang des Daten-RAMs
;kopiert. Nach Ende der bertragung wir die Startinformation
;"129" im RAM (Adr. 03FF) abgelegt und die Serienmessung
;angesprungen. Sie kann mit der Starttaste gestartet werden.

Messparameter  mov     r1,#52
               mov     r5,#8            ;8 Parameter
Mal8           inc     r1
               call    Empf
               mov     @r1,a
               djnz    r5,Mal8
               call    SystemRAM        ;Startinfo:
               mov     a,#129           ;Serienmessung
               call    SchreibeRAM
               call    AnfangRAM        ;Anfang 2k
               mov     r2,#52
               mov     r3,#8            ;Parameter an den
copy           inc     r2               ;RAM-Anfang schreiben
               mov     a,r2
               mov     r1,a 
               mov     a,@r1
               call    SchreibeRAM
               djnz    r3,copy
               jmp     Serie            ;Warten auf START

Endlos         jmp     Endlos           ;bis Start durch Reset


.org 200h
;Auslesen des Daten-RAMs. Der Hostrechner fordert jeweils
;mit einer "1" ein Byte an und bricht mit "0" ab.

Lesen          call    AnfangRAM        ;Anfang 2k
Leseloop       call    Empf             ;"1" oder "0" erwartet
               jz      Leseende         ;Ende, wenn "0"
               call    LiesRAM          ;auslesen
               call    Senden           ;Datenbyte zurck
               jmp     Leseloop    
Leseende       jmp     BefRS            ;nchstes Kommando


;Beschreiben des Daten-RAMs. Die Zelle fordert jeweils ein
;Byte durch Senden eines beliebigen Bytes an.
;Der Hostrechner antwortet mit "1" und dem Datenbyte oder
;mit "0" fr "Ende"

Schrb          call    AnfangRAM        ;Anfang 2k
Schrloop       call    Senden           ;Anforderung
               call    Empf             ;"0" oder "1" erwartet
               jz      Schrende         ;Ende, wenn "0"
               call    Empf             ;Datenbyte
               call    SchreibeRAM      ;abspeichern
               jmp     Schrloop
Schrende       jmp     BefRS 


;Direkt Messung ber den A/D-Wandler ohne Abspeichern.
;Es wird die Kanalnummer empfangen und das Ergenis gesendet.
;Abbruch, wenn die Kanalnummer "0" erscheint

Direkt         call    Empf             ;Kanalnummer
               jz      DirektEnde       ;Ende, wenn "0"
               call    Messen
               call    Senden
               jmp     Direkt
DirektEnde     jmp     BefRS 

;Eine einzelne direkt Messung. Wie die vorige Routine, aber
;ohne Wiederholungsschleife

Direkt1        call    Empf
               call    Messen
               call    Senden
               clr     a      
               jmp     BefRS

;Serienmessung fr die eingestellten Kanle und Intervallzeiten
;Die Anzahl wird fr jede Serie in den aktuellen Zhler (51/52)
;kopiert, den das Unterprogramm "Block" verwendet.

Serie          call    AnfangRAM  
               mov     r2,#52
               mov     r3,#8           
copyback       call    LiesRAM
               mov     r6,a
               inc     r2               ;Infos vom RAM-Anfang 
               mov     a,r2             ;lesen
               mov     r1,a 
               mov     a,r6
               mov     @r1,a
               djnz    r3,copyback
               call    WarteT0          ;Startsignal abwarten
NextSerie      mov     r0,#54           ;Anzahl/Serie 53/54 n. 51/52
               mov     r1,#52
               mov     a,@r0
               jnz     Nicht0
               inc     a                ;wenn Lowbyte = 0     
Nicht0         mov     @r1,a
               dec     r1
               dec     r0
               mov     a,@r0
               inc     a
               mov     @r1,a
               en      i                ;Interrupt frei
               mov     a,#248           ;Timer-Start
               mov     t,a
               strt    t
Messloop       mov     r1,#55           ;1. aktiver Kanal
               mov     a,@r1
               jz      Nr2
               call    Messen
               call    SchreibeRAM      ;Mewert abspeichern
               call    Warten
Nr2            mov     r1,#56           ;2. aktiver Kanal
               mov     a,@r1
               jz      Nr3
               call    Messen
               call    SchreibeRAM      ;Mewert abspeichern
               call    Warten
Nr3            mov     r1,#57           ;3. aktiver Kanal
               mov     a,@r1
               jz      Nr4
               call    Messen
               call    SchreibeRAM      ;Mewert abspeichern
               call    Warten
Nr4            mov     r1,#58           ;4. aktiver Kanal
               mov     a,@r1
               jz      Nr5
               call    Messen
               call    SchreibeRAM      ;Mewert abspeichern
               call    Warten
Nr5            jmp     Block
BlockOK        mov     r1,#59           ;Adr 59: Wait-high
               mov     a,@r1
               mov     r5,a             ;warten high
               inc     r5
spr2           djnz    r5,spr3
               jmp     spr4
spr3           mov     r4,#0
wait1          call    Warten
               djnz    r4,wait1
               jmp     spr2
spr4           mov     r1,#60 
               mov     a,@r1
               mov     r4,a
               inc     r4
spr5           djnz    r4,wait2         ;Warteschleife
               jmp     Messloop
wait2          call    Warten
               jmp     spr5

;Zhlt die Messungen mit und geht in erneute Mebereitschft,
;wenn eine Serie abgelaufen ist.

Block          mov     r1,#52
               mov     a,@r1
               dec     a
               mov     @r1,a
               jnz     Bl1
               dec     r1
               mov     a,@r1
               dec     a
               mov     @r1,a
               jnz     Bl1
               mov     r0,#53
               mov     a,@r0
               inc     a
               mov     @r1,a
               inc     r1
               inc     r0
               mov     a,@r0
               jnz     NoNull
               inc     a
NoNull         mov     @r1,a
Endlos2        call    WarteT0        ;bis weiter durch Start
               jmp     NextSerie
Bl1            jmp     BlockOK

;Endlosschleife mit abgeschalteter Startinformation

Stop           call    SystemRAM      ;Startinfo = 0
               mov     a,#0
               call    SchreibeRAM
               jmp     Stop

;Stellt die Adrepointer auf 03FF ein.
;Lt P26 unverndert

SystemRAM      mov      r1,#61         ;Adresse Hi
               in       a,p2
               anl      a,#0C3h
               orl      a,#03h
               mov      @r1,a          ;page3
               inc      r1             ;Adresse Lo
               mov      @r1,#0FFh      ;Adresse 03FF
               ret

;Wartet auf die Taste "Start" oder auf ein Byte "9" vom
;Hostrechner. Wird eine "0" empfangen, erfolgt ein Srung
;zur Interrupt-Routine und damit ein Neustart.

WarteT0        dis      i              ;Interrupt abschalten
               jni      RSweiter       ;Startbit?
               jnt0     WarteT0        ;wenn noch gedrckt
T0high         jni      RSweiter       ;Startbit?
               jt0      T0high         ;wenn nicht gedrckt
               en       i              ;Interrupt wieder frei
               ret
RSweiter       call     Startbit       ;Byte empfangen
               jz       Schluss
               ret
Schluss        jmp      Inter


.org 300h
;Ausgabe eines Bytes vom Hostrechner an Port 1

Port1          call    Empf
               outl    p1,a
               jmp     BefRS

;Auslesen des Ports 1 durch den Hostrechner

LiesPort1      in      a,p1
               call    Senden
               jmp     BefRS

;Setzen (1) oder Rcksetzen (0) von P26

Port2          call    Empf
               jb0     Port2an         ;"1"
               anl     p2,#0BFh        ;wenn "0"
               jmp     BefRS
Port2an        orl     p2,#40h
               jmp     BefRS

;Auslesen der Leitung P26 durch den Hostrechner
;Zurckgesendet wird "0" oder "1"

LiesPort2      in      a,p2
               rl      a               ;Bit verschieben
               rl      a
               anl     a,#1
               call    Senden
               jmp     BefRS


;Auslesen des Zustands der Starttaste durch den Hostrechner

LiesT0         mov     a,#0
               jnt0    T0Ende
               mov     a,#1
T0Ende         ret  


;Auslesen einer beliebigen Adressen des internen RAMs durch
;den Hostrechner.

LiesIRAM       call    Empf          ;Adresse
               mov     r0,a
               mov     a,@r0
               call    Senden        ;Datum
               jmp     BefRS

;Beschreiben einer beliebigen Adressen des internen RAMs durch
;den Hostrechner.

SchrbIRAM      call    Empf          ;Adresse
               mov     r0,a
               call    Empf          ;Datum
               mov     @r0,a
               jmp     BefRS

;Auslesen einer beliebigen Adressen des externen RAMs durch
;den Hostrechner.

LiesERAM       call    Empf          ;Adresse, high
               orl     a,#0C0h       ;P26...P27 high
               outl    p2,a
               call    Empf          ;Adresse, low
               mov     r0,a
               movx    a,@r0
               call    Senden        ;Datum
               jmp     BefRS

;Beschreiben einer beliebigen Adressen des externen RAMs durch
;den Hostrechner.

SchrbERAM      call    Empf          ;Adresse, high
               orl     a,#0C0h
               outl    p2,a
               call    Empf          ;Adresse, low
               mov     r0,a
               call    Empf          ;Datum
               movx    @r0,a
               jmp     BefRS

;Laden eines User-Programms: Jedes Byte wird erst durch
;ein beliebiges Byte der Zelle angefordert. Der
;Hostrechner sendet danach jeweils eine "1" und das
;Programmbyte. Die Programmbytes werden ab C400 (1k)
;abgespeichert. Beendigung der bertragung erfolgt
;durch ein Steuerbyte "0" des Hostrechners.

Proglad        mov     r1,#61           ;Adresse Hi
               mov     @r1,#0C4h        ;page4, 1k
               inc     r1               ;Adresse Lo
               mov     @r1,#0         
Progloop       call    Senden           ;Anforderung
               call    Empf             ;"1" oder "0" erwartet
               jz      Progladende      ;Ende, wenn "0"
               call    Empf             ;Programmbyte holen
               call    SchreibeRAM      ;Wert ins RAM       
               jmp     Progloop
Progladende    jmp     BefRS            ;Warte Befehl oder Reset

;Sprung zum Userprogramm ab 1k, Interrupt freigegeben, so da
;es mit einem Interrupt abgeschaltet werden kann

Progsta        en      i
               jmp     400h

;Paralleler Interface-Bus:
;Zufriff auf die Adressen 0...127 des I/O-Bus
;Auslesen, wenn Bit 7 gesetzt ist, sonst Schreiben
;Ende nach einer I/O-Aktion

PIB1           orl     p2,#20h            ;I/O-Bereich aktiv
               call    Empf
               jb7     Read1              ;Lesen
               mov     r0,a               ;Adresse nach r0
               call    Empf               ;Datum holen
               movx    @r0,a              ;zum I/O-Bus
               clr     a
               jmp     BefRS              ;neues Kommando
Read1          anl     a,#7Fh             ;Bit 7 zurcksetzen
               mov     r0,a               ;Adresse nach R0
               movx    a,@r0              ;I/O-Adresse auslesen
               call    Senden             ;Datum zurcksenden
               clr     a
               jmp     BefRS              ;neues Kommando

.end
